## Optimizing solver

### Debugging Vector model 1

#### Questions

- [x] How many times do the system of equations gets solved?
    - Without caching is 1 per scalar field x 2 (centers and corners) x n_octree levels

- [x] How many iterations we need to reach the solution?
  - Model 1 takes 5000 iterations (actually starts to diverge after 4k)
   
- [ ] Has Pykeops become slower with the latest additions to the gradient?

- [x] Is the Jacobi pre-conditioner bad for all cases?
  - Model 1:
    - Numpy Jacobi: Converge in
      - 1602 iterations and reach 5000
      - time 150 sec
      - More or less good results: Mesh closed
    - Numpy No jacobi
      - 1018 iterations and reach 5000
      - time 150 sec too
      - Results similar? I would say maybe a bit worse
    - Pykeosp No jacobi
      - 92 iterations and reach 5000
      - time 324 (all on running the solver)
- [ ] Can be that pykeops is faster than invert the matrix but still slower that any other CG
  - Since the matrix is already constructed, it makes sense
    - [ ] Then which cases is worth using pykeops? The number of iterations will need to be rather small
     Will it make sense on edits reusing the previous weights? This is going to need a hell of orchestrator
- [ ] How much memory takes numpy direct, numpy cg and pykeops cg
  - numpy direct: 1.5 or so
  - numpy cg: 1.25
  - pykeops cg: 1.1
  - **Note** Now the exporting takes quite a lot of memory



### Experiments conclusions
- Using pykeops CG to solve a ill posed problem is not realistic 
  - if the model fits in memory probably the best thing to do is make the first run in torch an use the weights as initial point
  - if the model does not fit in memory we should try to construct the sparse version of it and try to run the incomplete cholesky decomposition

- I didn't find any improvement using the Jacobi pre-conditioner. Mostly the opposite
- With ichol we get different results with numpy or pykeops
	- Pykeops
- ichol does not give super good results either at least before the convergence happens
  - Model 1 converge **without** ichol on 1290 and 8518
  - Model 1 converge **With** ichol 496 (506 in pykeops) 5080 (4995 in pykeops)
	

### TODO:

- [x] Clean solver interface
- [ ] Add citation for pymatting

### Things to try:
- [x] Pykeops as linear operator to use exact solver
  - Does not look good. Probably is not even possible mathematically
- [x] Falkon

### Optimal solver

- Tools we have:
  - keops
  - CG
  - Incomplete cholesky decomposition
  - passing the weights as initial point
- Variables to choose what to use:
  - Size of the covariance matrix
  - Number of CG iterations we are going to need. This depends on:
    - Conditional number
    - Do we have weights

- **Strategy**:
  - If the Number of CG iterations is a handful -> **use keops**
  - If the number of CG iterations is large:
    - Use **direct solver** if the matrix fits in memory
    - Then for changes hopefully we can use the weights as initial point and use **keops**
  - If the matrix does not fit in memory:
    - Construct the sparse version of the matrix
    - Use **incomplete cholesky decomposition**
      - Once we have the decomposition is better to use **keops** to solve the system (except if the number of iterations has to be very large) 
  - Optimizing nugget effects still seems the best way to do this
  - If memory is not an issue. **Direct solver with torch and keops for exporting seems to be the best option**


#### Notes
- [ ] I need to make similar default env file for gempy itself and using the default when we call the engine or whatever



